@@ -1,5 +1,5 @@
 package ETL::Yertl;
-our $VERSION = '0.028';
+our $VERSION = '0.029';
 # ABSTRACT: ETL with a Shell
 
 use strict;
@@ -56,7 +56,7 @@ ETL::Yertl - ETL with a Shell
 
 =head1 VERSION
 
-version 0.028
+version 0.029
 
 =head1 SYNOPSIS
 
@@ -179,12 +179,6 @@ set the C<YERTL_FORMAT> environment variable to C<"json">.
 
 Doug Bell <preaction@cpan.org>
 
-=head1 CONTRIBUTOR
-
-=for stopwords Doug Bell
-
-Doug Bell <doug@preaction.me>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2016 by Doug Bell.
